# Roadmap

## Other servies, others clouds
Implementing an MVP with only AWS - EKS in mind. I would like to add more AWS services and even more clouds. So, after getting the core logic down the internal structure will focus on enabling reuse of the same patterns, interfaces and testing to make this sort of extentsion natural and relatively easy.

## Audit mode
Initial focus on a scan against one single service given a name. In the future this can be extended to audit for all services in an account or region.
